Crate af_iperps

Move types for Aftermath’s Perpetuals package

Re-exports

pub use self::market::MarketParams;
pub use self::market::MarketState;
pub use self::orderbook::Order;
pub use self::position::Position;

Modules

account
admin
clearing_house
errors
event_ext
event_instance
events
graphqlgraphql
keys
market
math
order_helpers
order_id
orderbook
ordered_map
position
registry
sloslo
Helpers for stop-loss orders.
stop_orders
subaccount

Constants

TESTNET_PACKAGE_VERSIONS
Package IDs of the perpetuals contract versions published on testnet, in order of its versions.

Type Aliases

Account
AccountTypeTag
AsksMapDofWrapper
Dynamic object field wrapper for the asks Map ID.
BidsMapDofWrapper
Dynamic object field wrapper for the bids Map ID.
ClearingHouse
ClearingHouseTypeTag
OrderLeafDf
Dynamic field storing a leaf in a Map of Orders.
OrderbookDofWrapper
Dynamic object field wrapper for the Orderbook ID.
PositionDf
Dynamic field storing a Position.
StopOrderTicket
StopOrderTicketTypetag
SubAccount
SubAccountTypeTag
Vault
VaultTypeTag